@@ -1,4 +1,4 @@
-.charToDistFunc = function(distribution, type = "q") {                                                           ####   .CHARTODISTFUNC-FUNCTION
+.charToDistFunc = function(distribution, type = "q") {
     fun = NULL
     if (identical("beta", distribution)) 
         fun = eval(parse(text = paste(type, "beta", sep = "")))
@@ -12,10 +12,10 @@
         fun = eval(parse(text = paste(type, "f", sep = "")))
     if (identical("geometric", distribution)) 
         fun = eval(parse(text = paste(type, "geom", sep = "")))
-    if (identical("log-normal", distribution) || identical("lognormal", distribution))         ####
+    if (identical("log-normal", distribution) || identical("lognormal", distribution)) 
         fun = eval(parse(text = paste(type, "lnorm", sep = "")))
-    if (identical("log-normal3", distribution) || identical("lognormal3", distribution))       ####
-        fun = eval(parse(text = paste(type, "lnorm3", sep = "")))                              ####
+    if (identical("log-normal3", distribution) || identical("lognormal3", distribution)) 
+        fun = eval(parse(text = paste(type, "lnorm3", sep = "")))
     if (identical("logistic", distribution)) 
         fun = eval(parse(text = paste(type, "logis", sep = "")))
     if (identical("negative binomial", distribution)) 
@@ -28,10 +28,12 @@
         fun = eval(parse(text = paste(type, "t", sep = "")))
     if (identical("weibull", distribution)) 
         fun = eval(parse(text = paste(type, "weibull", sep = "")))
-    if (identical("weibull3", distribution))                                                   ####
-        fun = eval(parse(text = paste(type, "weibull3", sep = "")))                            ####
+    if (identical("weibull3", distribution)) 
+        fun = eval(parse(text = paste(type, "weibull3", sep = "")))
     if (identical("gamma", distribution)) 
         fun = eval(parse(text = paste(type, "gamma", sep = "")))
+    if (identical("gamma3", distribution)) 
+        fun = eval(parse(text = paste(type, "gamma3", sep = "")))
     return(fun)
 }
 .lfrm = function(wholeList, filterList) {
