@@ -3,25 +3,24 @@ fracChoose = function() {
     genList = list(6 * 9)
     genList = list(c("C = AB"), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), 
         c(NULL), c("D = ABC"), c("D = AB", "E = AC"), c("D = AB", "E = AC", "F = BC"), c("D = AB", 
-            "E = AC", "F = BC", "G = ABC"), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), 
-        c("E = ABCD"), c("E = ABC", "F = BCD"), c("E = ABC", "F = BCD", "G = ACD"), c("E = BCD", 
-            "F = ACD", "G = ABC", "H = ABD"), c("E = ABC", "F = BCD", "G = ACD", "H = ABD", "J = ABCD"), 
-        c("E = ABC", "F = BCD", "G = ACD", "H = ABD", "J = ABCD", "K = AB"), c("E = ABC", "F = BCD", 
-            "G = ACD", "H = ABD", "J = ABCD", "K = AB", "L = AC"), c(NULL), c(NULL), c(NULL), c("F = ABCDE"), 
-        c("F = ABCD", "G = ABDE"), c("F = ABC", "G = ABD", "H = BCDE"), c("F = BCDE", "G = ACDE", 
-            "H = ABDE", "J = ABCE"), c("F = ABCD", "G = ABCE", "H = ABDE", "J = ACDE", "K = BCDE"), 
-        c("F = ABC", "G = BCD", "H = CDE", "J = ACD", "K = AEF", "L = ADEF"), c(NULL), c(NULL), c(NULL), 
-        c(NULL), c("G = ABCDEF"), c("G = ABCD", "H = ABEF"), c("G = ABCD", "H = ACEF", "J = CDEF"), 
-        c("G = BCDF", "H = ACDF", "J = ABDE", "K = ABCE"), c("G = CDE", "H = ABCD", "J = ABF", "K = BDEF", 
-            "L = ADEF"), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c("H = ABCDEFG"), c("H = ACDFG", 
-            "J = BCEFG"), c("H = ABCG", "J = BCDE", "K = ACDF"), c("H = ABCG", "J = BCDE", "K = ACDF", 
-            "L = ABCDEFG"))
+            "E = AC", "F = BC", "G = ABC"), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c("E = ABCD"), 
+        c("E = ABC", "F = BCD"), c("E = ABC", "F = BCD", "G = ACD"), c("E = BCD", "F = ACD", "G = ABC", 
+            "H = ABD"), c("E = ABC", "F = BCD", "G = ACD", "H = ABD", "J = ABCD"), c("E = ABC", "F = BCD", 
+            "G = ACD", "H = ABD", "J = ABCD", "K = AB"), c("E = ABC", "F = BCD", "G = ACD", "H = ABD", 
+            "J = ABCD", "K = AB", "L = AC"), c(NULL), c(NULL), c(NULL), c("F = ABCDE"), c("F = ABCD", 
+            "G = ABDE"), c("F = ABC", "G = ABD", "H = BCDE"), c("F = BCDE", "G = ACDE", "H = ABDE", 
+            "J = ABCE"), c("F = ABCD", "G = ABCE", "H = ABDE", "J = ACDE", "K = BCDE"), c("F = ABC", 
+            "G = BCD", "H = CDE", "J = ACD", "K = AEF", "L = ADEF"), c(NULL), c(NULL), c(NULL), c(NULL), 
+        c("G = ABCDEF"), c("G = ABCD", "H = ABEF"), c("G = ABCD", "H = ACEF", "J = CDEF"), c("G = BCDF", 
+            "H = ACDF", "J = ABDE", "K = ABCE"), c("G = CDE", "H = ABCD", "J = ABF", "K = BDEF", "L = ADEF"), 
+        c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c("H = ABCDEFG"), c("H = ACDFG", "J = BCEFG"), 
+        c("H = ABCG", "J = BCDE", "K = ACDF"), c("H = ABCG", "J = BCDE", "K = ACDF", "L = ABCDEFG"))
     resList = list(6 * 9)
-    resList = list(c(3), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), 
-        c(NULL), c(4), c(3), c(3), c(3), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(5), 
-        c(4), c(4), c(4), c(3), c(3), c(3), c(NULL), c(NULL), c(NULL), c(6), c(4), c(4), c(4), c(4), 
-        c(4), c(NULL), c(NULL), c(NULL), c(NULL), c(7), c(5), c(4), c(4), c(4), c(NULL), c(NULL), 
-        c(NULL), c(NULL), c(NULL), c(8), c(6), c(5), c(5))
+    resList = list(c(3), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), 
+        c(4), c(3), c(3), c(3), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(5), c(4), c(4), 
+        c(4), c(3), c(3), c(3), c(NULL), c(NULL), c(NULL), c(6), c(4), c(4), c(4), c(4), c(4), c(NULL), 
+        c(NULL), c(NULL), c(NULL), c(7), c(5), c(4), c(4), c(4), c(NULL), c(NULL), c(NULL), c(NULL), 
+        c(NULL), c(8), c(6), c(5), c(5))
     facMat = matrix(rep(3:11, 6), ncol = 9, byrow = TRUE)
     runMat = matrix(c(rep(2^2, 9), rep(2^3, 9), rep(2^4, 9), rep(2^5, 9), rep(2^6, 9), rep(2^7, 9)), 
         ncol = 9, byrow = TRUE)
