@@ -1,7 +1,7 @@
 setClass(Class = "mixDesign", representation = representation(name = "character", factors = "list", 
     total = "numeric", lower = "numeric", design = "data.frame", designType = "character", pseudo = "data.frame", 
-    response = "data.frame", Type = "data.frame", block = "data.frame", runOrder = "data.frame", 
-    standardOrder = "data.frame", desireVal = "list", desirability = "list", fits = "data.frame"))
+    response = "data.frame", Type = "data.frame", block = "data.frame", runOrder = "data.frame", standardOrder = "data.frame", 
+    desireVal = "list", desirability = "list", fits = "data.frame"))
 setMethod("factors", "mixDesign", function(x) x@factors)
 setReplaceMethod("factors", "mixDesign", function(x, value) {
     if (length(value) != ncol(x@pseudo)) 
@@ -228,8 +228,8 @@ setReplaceMethod("lows", "mixDesign", function(object, value) {
     return(frameOut)
 }
 .simplexCentroid(4)
-mixDesign = function(p, n = 3, type = "lattice", center = TRUE, axial = FALSE, delta, 
-    replicates = 1, lower, total = 1, randomize, seed) {
+mixDesign = function(p, n = 3, type = "lattice", center = TRUE, axial = FALSE, delta, replicates = 1, 
+    lower, total = 1, randomize, seed) {
     DB = FALSE
     frameOut = NA
     out = new("mixDesign")
