@@ -1,6 +1,12 @@
-paretoPlot = function(fdo, threeWay = FALSE, abs = TRUE, decreasing = TRUE, na.last = NA, 
-    alpha = 0.05, xlim, ylim, xlab, ylab, main, ...) {
+paretoPlot = function(fdo, threeWay = FALSE, abs = TRUE, decreasing = TRUE, na.last = NA, alpha = 0.05, 
+    response = NULL, xlim, ylim, xlab, ylab, main, single = TRUE, ...) {
     DB = FALSE
+    if (single == FALSE) 
+        par(mfrow = .splitDev(length(response(fdo)))[[2]])
+    if (is.null(response) == FALSE) {
+        temp = response(fdo)[response]
+        response(fdo) = temp
+    }
     ylimMissing = FALSE
     if (missing(ylim)) 
         ylimMissing = TRUE
@@ -16,13 +22,14 @@ paretoPlot = function(fdo, threeWay = FALSE, abs = TRUE, decreasing = TRUE, na.l
     effect.list = vector("list")
     for (j in 1:ncol(response(fdo))) {
         par(mar = c(5.1, 4.1, 4.1, 4.1))
-        if (j > 1) {
+        if (j > 1 && single == TRUE) {
             dev.new()
             par(mar = c(5.1, 4.1, 4.1, 4.1))
         }
         if (!any(is.na(response(fdo)[, j]))) {
             if (missing(ylab)) 
-                ylab = names(response(fdo))[j]
+                ylabel = names(response(fdo))[j]
+            else ylabel = ylab
             form = paste("response(fdo)[,", j, "]~")
             for (i in 1:ncol(cube(fdo))) {
                 form = paste(form, names(cube(fdo))[i], sep = "")
@@ -58,7 +65,7 @@ paretoPlot = function(fdo, threeWay = FALSE, abs = TRUE, decreasing = TRUE, na.l
                     ylim <- (range(c(0, abs(effect), 1.3 * ME))) * 1.1
                   else ylim <- (range(c(effect, -1.3 * ME, 1.3 * ME))) * 1.1
                 if (abs) {
-                  xVals = barplot(abs(effect), las = 2, main = main, xlab = xlab, ylim = ylim, ylab = ylab, 
+                  xVals = barplot(abs(effect), las = 2, main = main, xlab = xlab, ylim = ylim, ylab = ylabel, 
                     ...)
                   abline(h = ME, col = "red")
                   abline(h = SME, col = "red")
@@ -68,7 +75,7 @@ paretoPlot = function(fdo, threeWay = FALSE, abs = TRUE, decreasing = TRUE, na.l
                   text(x = xVals[2], y = SME, "SME", pos = 3)
                 }
                 else {
-                  xVals = barplot(effect, las = 2, main = main, xlab = xlab, ylim = ylim, ylab = ylab, 
+                  xVals = barplot(effect, las = 2, main = main, xlab = xlab, ylim = ylim, ylab = ylabel, 
                     ...)
                   abline(h = c(-ME, ME), col = "red")
                   abline(h = c(-SME, SME), col = "red")
@@ -88,8 +95,8 @@ paretoPlot = function(fdo, threeWay = FALSE, abs = TRUE, decreasing = TRUE, na.l
             else {
                 if (missing(main)) 
                   main = "Standardized main effects and interactions"
-                effect = ((summary(lm.1)$coefficients[-pmatch("(Intercept)", names(coef(lm.1))), 
-                  1])/(summary(lm.1)$coefficients[-pmatch("(Intercept)", names(coef(lm.1))), 2]))
+                effect = ((summary(lm.1)$coefficients[-pmatch("(Intercept)", names(coef(lm.1))), 1])/(summary(lm.1)$coefficients[-pmatch("(Intercept)", 
+                  names(coef(lm.1))), 2]))
                 if (all(is.na(effect))) 
                   stop("effects could not be calculated")
                 effect = effect[!is.na(effect)]
@@ -116,7 +123,7 @@ paretoPlot = function(fdo, threeWay = FALSE, abs = TRUE, decreasing = TRUE, na.l
                 effect = effect[order(abs(effect), na.last = TRUE, decreasing = decreasing)]
                 effect = round(effect, 3)
                 if (abs) {
-                  xVals = barplot(abs(effect), las = 2, main = main, xlab = xlab, ylim = ylim, ylab = ylab, 
+                  xVals = barplot(abs(effect), las = 2, main = main, xlab = xlab, ylim = ylim, ylab = ylabel, 
                     ...)
                   if (length(xVals) >= 1) 
                     for (i in 1:length(xVals)) {
@@ -124,7 +131,7 @@ paretoPlot = function(fdo, threeWay = FALSE, abs = TRUE, decreasing = TRUE, na.l
                     }
                 }
                 else {
-                  xVals = barplot(effect, las = 2, main = main, xlab = xlab, ylim = ylim, ylab = ylab, 
+                  xVals = barplot(effect, las = 2, main = main, xlab = xlab, ylim = ylim, ylab = ylabel, 
                     ...)
                   if (length(xVals) >= 1) 
                     for (i in 1:length(xVals)) {
