@@ -8,8 +8,7 @@
         for (x2 in y) {
             zy = zy + 1
             z[zx, zy] = 1/(2 * pi * sigma1 * sigma2 * sqrt(1 - rho^2)) * exp(-1/(2 * (1 - rho^2)) * 
-                (((x1 - mu1)/sigma1)^2 - 2 * rho * (x1 - mu1)/sigma1 * (x2 - mu2)/sigma2 + ((x2 - 
-                  mu2)/sigma2)^2))
+                (((x1 - mu1)/sigma1)^2 - 2 * rho * (x1 - mu1)/sigma1 * (x2 - mu2)/sigma2 + ((x2 - mu2)/sigma2)^2))
         }
         zy = 0
     }
