@@ -29,8 +29,7 @@ setMethod("[", signature(x = "steepAscent", i = "ANY", j = "ANY"), function(x, i
         x@X[i, j]
     else x@response[i, j - bound]
 })
-setMethod("as.data.frame", "steepAscent", function(x, row.names = NULL, optional = FALSE, 
-    ...) {
+setMethod("as.data.frame", "steepAscent", function(x, row.names = NULL, optional = FALSE, ...) {
     return(cbind(x@X, x@response))
 })
 as.data.frame.steepAscent = function(x, row.names = NULL, optional = FALSE, ...) {
