@@ -1,5 +1,5 @@
-contourPlot3 = function(x, y, z, response, data = NULL, main, xlab, ylab, zlab, border, 
-    form = "linear", col = 1, col.text, cex.axis, axes = TRUE, steps, factors) {
+contourPlot3 = function(x, y, z, response, data = NULL, main, xlab, ylab, zlab, border, form = "linear", 
+    col = 1, col.text, cex.axis, axes = TRUE, steps, factors) {
     DB = FALSE
     out = list()
     mdo = data
@@ -87,7 +87,7 @@ contourPlot3 = function(x, y, z, response, data = NULL, main, xlab, ylab, zlab,
     v = seq(acc, 1, length = acc)
     w = c(seq(2, acc, length = acc/2), seq(acc, 2, length = acc/2))
     mat[outer(w, v, `+`) <= acc] = NA
-    .mfc(mat, main = main, color = col, axes = FALSE, key.axes = axis(4))
+    .mfc(mat, main = main, col = col, axes = FALSE, key.axes = axis(4))
     if (axes == TRUE) {
         segments(0.5, 0, 0.5, 1, col = col.axis)
         coox1 = rep(0.49, 11)
@@ -124,8 +124,8 @@ contourPlot3 = function(x, y, z, response, data = NULL, main, xlab, ylab, zlab,
     mtext(zlab, 1, at = 1.025, cex = 1.5)
     invisible(mat)
 }
-wirePlot3 = function(x, y, z, response, data = NULL, main, xlab, ylab, zlab, form = "linear", 
-    phi, theta, col = 1, steps, factors) {
+wirePlot3 = function(x, y, z, response, data = NULL, main, xlab, ylab, zlab, form = "linear", phi, 
+    theta, col = 1, steps, factors) {
     DB = FALSE
     out = list()
     mdo = data
@@ -230,11 +230,10 @@ wirePlot3 = function(x, y, z, response, data = NULL, main, xlab, ylab, zlab, for
     }
     maxim = max(mat, na.rm = TRUE) * acc
     minim = min(mat, na.rm = TRUE) * acc
-    per = persp(x = seq(0, acc, length = acc), y = seq(0, acc * sca, length = ncmat), mat * acc, 
-        phi = .phi, theta = .theta, scale = TRUE, col = "transparent", border = FALSE, box = FALSE, 
-        main = main, xlab = xlab, ylab = ylab)
-    lineList = contourLines(x = seq(0, acc, length = acc), y = seq(0, acc * sca, length = ncmat), 
-        mat)
+    per = persp(x = seq(0, acc, length = acc), y = seq(0, acc * sca, length = ncmat), mat * acc, phi = .phi, 
+        theta = .theta, scale = TRUE, col = "transparent", border = FALSE, box = FALSE, main = main, 
+        xlab = xlab, ylab = ylab)
+    lineList = contourLines(x = seq(0, acc, length = acc), y = seq(0, acc * sca, length = ncmat), mat)
     for (i in seq(along = lineList)) lines(trans3d(lineList[[i]]$x, lineList[[i]]$y, z = minim, pmat = per))
     if (.phi < 90) {
         lines(trans3d(x = seq(0, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = maxim, 
@@ -253,8 +252,8 @@ wirePlot3 = function(x, y, z, response, data = NULL, main, xlab, ylab, zlab, for
     if (.theta > 156 && .theta < 323) {
         lines(trans3d(x = acc, y = 0, z = minim:maxim, pmat = per), lty = 2)
     }
-    lines(trans3d(x = seq(0, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = minim, 
-        pmat = per), lty = 1, lwd = 2)
+    lines(trans3d(x = seq(0, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = minim, pmat = per), 
+        lty = 1, lwd = 2)
     lines(trans3d(x = seq(acc, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = minim, 
         pmat = per), lty = 1, lwd = 2)
     lines(trans3d(x = 0:acc, y = 0, z = minim, pmat = per), lty = 1, lwd = 2)
